pm4py.algo.discovery.dfg.variants package
=========================================

Submodules
----------

pm4py.algo.discovery.dfg.variants.case\_attributes module
---------------------------------------------------------

.. automodule:: pm4py.algo.discovery.dfg.variants.case_attributes
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.dfg.variants.freq\_triples module
------------------------------------------------------

.. automodule:: pm4py.algo.discovery.dfg.variants.freq_triples
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.dfg.variants.native module
-----------------------------------------------

.. automodule:: pm4py.algo.discovery.dfg.variants.native
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.dfg.variants.performance module
----------------------------------------------------

.. automodule:: pm4py.algo.discovery.dfg.variants.performance
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.dfg.variants
   :members:
   :undoc-members:
   :show-inheritance:
